import javafx.application.Platform;
import javafx.scene.control.Alert;
import javafx.scene.control.ButtonType;
import javafx.scene.paint.Color;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

public class UpdateThread extends Thread
{
	BufferedReader reader;
	GameState gameState;
	Plateau plateau;

	public UpdateThread(Process program, GameState gameState, Plateau plateau)
	{
		this.reader = new BufferedReader(new InputStreamReader(program.getInputStream()));
		this.gameState = gameState;
		this.plateau = plateau;
	}


	public void run()
	{
		boolean running = true;
		while(running)
			try
			{
				String line = reader.readLine();
				System.out.println(line);
				if(line == null)
					running = false;
				else
				{
					if (line.contains("{"))
					{
						gameState.update(line.substring(line.indexOf("{"), line.lastIndexOf("}") + 1));
						Platform.runLater(() ->
						{
							for(Case c : plateau.getGrille())
							{
								c.setNbFish(gameState.getNbFish(c.getRang()));
								switch (c.getNbFish())
								{
									case 0:
										c.getCaseFX().setFill(Color.BLUE);
										break;
									case 1:
										c.getCaseFX().setFill(Color.GREEN);
										break;
									case 2:
										c.getCaseFX().setFill(Color.YELLOW);
										break;
									case 3:
										c.getCaseFX().setFill(Color.RED);
										break;
								}
							}
							// TODO: 4/27/16 update GUI from state
						});
					}
				}
			} catch (IOException e)
			{
				running = false;
				Platform.runLater(() ->
				{
					Alert alert = new Alert(Alert.AlertType.ERROR, "Error during reading from penguin program!", ButtonType.FINISH);
					e.printStackTrace();
					alert.showAndWait();
					System.exit(1);
				});
			}
	}
}
